km3modules.k40.K40BackgroundSubtractor
======================================

.. currentmodule:: km3modules.k40

.. autoclass:: K40BackgroundSubtractor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~K40BackgroundSubtractor.__init__
      ~K40BackgroundSubtractor.add
      ~K40BackgroundSubtractor.configure
      ~K40BackgroundSubtractor.dump
      ~K40BackgroundSubtractor.expose
      ~K40BackgroundSubtractor.finish
      ~K40BackgroundSubtractor.get
      ~K40BackgroundSubtractor.get_corrected_counts
      ~K40BackgroundSubtractor.pre_finish
      ~K40BackgroundSubtractor.process
      ~K40BackgroundSubtractor.require
      ~K40BackgroundSubtractor.subtract_background
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~K40BackgroundSubtractor.name
   
   